@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2012 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2014 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -162,6 +162,26 @@ void SshProcess::tunnelLoop()
 #endif
 }
 
+#ifdef Q_OS_WIN
+#include <QSettings>
+void SshProcess::addPuttyReg(QString host, QString uuidStr)
+{
+    QSettings st("HKEY_CURRENT_USER\\Software\\SimonTatham\\PuTTY\\Sessions\\"+uuidStr,
+                 QSettings::NativeFormat);
+    st.setValue("HostName", host);
+    st.setValue("GssapiFwd", (uint) 1);
+    st.sync();
+}
+
+void SshProcess::rmPuttyReg(QString uuidStr)
+{
+    QSettings st("HKEY_CURRENT_USER\\Software\\SimonTatham\\PuTTY\\Sessions",
+                 QSettings::NativeFormat);
+    st.remove(uuidStr);
+    st.sync();
+}
+#endif
+
 void SshProcess::startNormal(const QString& cmd)
 {
     QUuid uuid = QUuid::createUuid();
@@ -181,15 +201,26 @@ void SshProcess::startNormal(const QString& cmd)
     }
     else
     {
+        QString host=masterCon->getHost();
         QString shcmd = "echo X2GODATABEGIN:" + uuidStr + "; "+cmd+"; echo X2GODATAEND:" + uuidStr;
         proc=new QProcess(this);
 #ifdef Q_OS_WIN
+        if(masterCon->get_kerberosDelegation())
+        {
+            addPuttyReg(host, uuidStr);
+            host = uuidStr;
+        }
         QString sshString="plink -batch -P "+
 #else
-        QString sshString=QString::null+"ssh"+ KEEPALIVE_OPTION +"-o GSSApiAuthentication=yes -o PasswordAuthentication=no -p "+
+        QString krbDelegOption=" -k ";
+        if(masterCon->get_kerberosDelegation())
+        {
+            krbDelegOption=" -K ";
+        }
+        QString sshString=QString::null+"ssh"+ KEEPALIVE_OPTION +krbDelegOption+" -o GSSApiAuthentication=yes -o PasswordAuthentication=no -p "+
 #endif
-                          QString::number(masterCon->getPort())+" "+
-                          masterCon->getUser()+"@"+ masterCon->getHost() +  " \""+shcmd+"\"";
+                          QString::number(masterCon->getPort())+" -l "+
+                          masterCon->getUser()+" "+ host +  " \""+shcmd+"\"";
 #ifdef DEBUG
         x2goDebug<<"running ssh:" <<sshString<<endl;
 #endif
@@ -421,6 +452,12 @@ void SshProcess::slotSshProcFinished(int exitCode, QProcess::ExitStatus exitStat
         normalExited=true;
 #ifdef DEBUG
     x2goDebug<<"ssh process exit code :"<<exitStatus;
+#endif
+#ifdef Q_OS_WIN
+    if(masterCon->useKerberos())
+    {
+        rmPuttyReg(procUuid);
+    }
 #endif
     slotChannelClosed(this,procUuid);
 }
