@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2012 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2014 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -46,6 +46,10 @@ private:
     }
 
     void tunnelLoop();
+#ifdef Q_OS_WIN
+    void    addPuttyReg(QString host, QString uuidStr);
+    void    rmPuttyReg(QString uuidStr);
+#endif
 
 private:
     SshMasterConnection* masterCon;
