@@ -615,7 +615,7 @@ Public key hash: </source>
     </message>
     <message>
         <source>pc105/us</source>
-        <translation>pc105/us</translation>
+        <translation type="obsolete">pc105/us</translation>
     </message>
     <message>
         <source>X2Go Client</source>
@@ -1142,7 +1142,7 @@ Unsaved documents will be lost</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;/b&gt;&lt;br&gt; (C. 2006-2012 &lt;b&gt;obviously nice&lt;/b&gt;: Oleksandr Shneyder, Heinz-Markus Graesing)&lt;br&gt;</source>
+        <source>&lt;/b&gt;&lt;br&gt; (C. 2005-2014 &lt;b&gt;obviously nice&lt;/b&gt;: Oleksandr Shneyder, Heinz-Markus Graesing)&lt;br&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1457,6 +1457,10 @@ Do you want to terminate the connection?
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Verification code:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -1913,6 +1917,10 @@ lpr -P hp_laserjet</source>
         <source>x2goclient is running in portable mode. You should use a path on your usb device to be able to access your data whereever you are</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Delegation of GSSAPI credentials to the server</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsWidget</name>
@@ -1976,18 +1984,6 @@ lpr -P hp_laserjet</source>
         <source>&amp;Identify all displays</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Keep current keyboard Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Keyboard layout:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Keyboard model:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Enable sound support</source>
         <translation type="unfinished"></translation>
@@ -2031,12 +2027,36 @@ sound system connections through firewalls</source>
     </message>
     <message>
         <source>pc105/us</source>
-        <translation type="unfinished">pc105/us</translation>
+        <translation type="obsolete">pc105/us</translation>
     </message>
     <message>
         <source>password</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Auto detect keyboard settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not configure keyboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure keyboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Model: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Layout: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Variant: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ShareWidget</name>
@@ -2183,6 +2203,14 @@ sound system connections through firewalls</source>
         <source>error reading tcp socket</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Failed to start SSH Client. Please check your installation and GSSApi configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Check your GSSApi configuration or choose another authentication method</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SshProcess</name>
